/*
		xref.h

   Functions available in xref.c
*/

#define ECCENTRIC_FILE 	"concentricities"
	
#define FIBER_KNOWN  1
#define OBJECT_KNOWN 2
#define SLIT_KNOWN   3
#define FOP_KNOWN    4
#define ACQ_KNOWN    5

#define NONE_FOUND   0
#define ONE_FOUND    1
#define MULTI_FOUND  2

#define FIRST_ACQ   	 801
#define FIRST_ACQ_CHAR   'I'

#define FIRST_FOP   	 901
#define FIRST_FOP_CHAR   'A'

#define PROBE 	 	 "P"

#ifndef RED
#define RED 	1	/* cable ordinals */
#define BLUE    2
#define AAAA    3
#define BBBB    4
#define CCCC    5
#define DDDD    6
#define EEEE    7
#define FFFF    8
#endif

#define RED_OFFSET   100
#define BLUE_OFFSET  200
#define AAAA_OFFSET  300
#define BBBB_OFFSET  400
#define CCCC_OFFSET  500
#define DDDD_OFFSET  600
#define EEEE_OFFSET  700
#define FFFF_OFFSET  800


#define INTACT  0
#define BROKEN  1


#define VOIDENTRY   -1

#define WRONG_FOOT  -2

#define OBJ_DEAD_ZONE 9

struct XrefItem{

   int fiber;
   int object;
   int slit;
   char cable;
};

typedef struct XrefItem xItem;


extern int eccenFlag;	/*  Flag to apply eccentricity correction */

extern void xRefLoad();
extern int  fiberBroken();
extern char slitToProbeID();
extern void eccenCalcVec();


extern void xRefClear( fibDB fibers[] );

extern int xRefFiber(  int theFiber, xItem *theList, aStar *stars[], fibDB fibers[]  );
extern int xRefObject( int theObject, xItem *theList, aStar *stars[], fibDB fibers[]  );
extern int xRefSlit( int theSlit, xItem *theList, aStar *stars[], fibDB fibers[]  );
extern int xRefProbe( char theProbe, xItem *theList, aStar *stars[], fibDB fibers[]  );

extern int fiberAtObject( int fiber, double tolerance );

extern int  userToInternalID( aStar *stars[], int targetID, int *internalID );

extern int  fibToFop( fibDB *fib );
extern int  fiberIsFop( int fiber );

extern int  fiberIsAssignedFop( int fiber, aStar *stars[], fibDB fibers[] );

extern int  fiberIsSky( int fiber, aStar *stars[], fibDB fibers[] );
extern int  fiberIsAssignedSky( int fiber, aStar *stars[], fibDB fibers[] );
extern int  fiberIsRandomSky(   int fiber, aStar *stars[], fibDB fibers[] );

extern int  fiberInCable( int fiber, char cableID );

extern char slitToProbeID( int id );

int fiberBroken( int id );
int fiberParked( int id );


